# Utility functions for Copypasta
# Copyright (c) Michael Craft 2010
# Released under the MIT License.

import csv, urllib, subprocess, sys, os

# Returns the text inside <response> tags
def parseResponse(response):
	s1, s2, s3 = response.partition('<response>')
	data, s4, s5 = s3.partition('</response>')
	return data

class PastaUtil:
	def __init__(self):
		# change directory to access config.txt
		path = os.path.dirname(__file__)
		if path != '':
			os.chdir(path)
		
		# Load config file.
		file = open('config.txt')
		reader = csv.reader(file)
		data = reader.next()
		self.name, self.password, self.server = reader.next() # We want the second line
		file.close()
		
		# Uses xsel on X11 (Linux / UNIX) systems, pbcopy / pbpaste on OSX, and included custom utilites on windows.
		if sys.platform == 'win32':
			self.setcmd = 'win32\setclipboard.exe'
			self.getcmd = 'win32\getclipboard.exe'
		elif sys.platform == 'darwin':
			self.setcmd = 'pbcopy'
			self.getcmd = 'pbpaste'
		else: # Assume X11 system.
			self.setcmd = ['xsel', '-bi']
			self.getcmd = ['xsel', '-b']

	# Get contents of a user's Copypasta clipboard
	def pastaPaste(self):
		data = urllib.urlencode((('type','pasta'), ('name',self.name), ('pass', self.password)))
		response = urllib.urlopen(self.server, data).read() # do the POST request
		response = parseResponse(response)
		print response
		return response

	# Sets the contents of a user's Copypasta clipboard
	def pastaCopy(self, pasta):
		data = urllib.urlencode((('type','copy'), ('name',self.name), ('pass', self.password), ('pasta', pasta)))
		response = urllib.urlopen(self.server, data).read() # do the POST request
		print parseResponse(response)
	
	def getClipboard(self):
		process = subprocess.Popen(self.getcmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin=subprocess.PIPE);
		stdout, stderr = process.communicate()
		return stdout

	def setClipboard(self, pasta):
		process = subprocess.Popen(self.setcmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin=subprocess.PIPE)
		process.communicate(pasta)
