﻿// Part of Copypasta
// Copyright (c) Michael Craft 2010
// Released under the MIT License.

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using libpasta;

namespace copypasta
{
	public partial class Form1 : Form
	{
		private const int MOD_ALT = 0x1;
		private const int MOD_CONTROL = 0x2;
		private const int WM_HOTKEY = 0x312;
		private const int COPY_PARAM = 0x430003;
		private const int PASTE_PARAM = 0x560003;

		private int keyId;
		private PastaUtil p = new PastaUtil();

		[DllImport("user32.dll")]
		[return: MarshalAs(UnmanagedType.Bool)]
		public static extern bool RegisterHotKey(IntPtr hWnd, int id, int fsModifiers, int vlc);

		public Form1()
		{
			InitializeComponent();
			keyId = this.GetHashCode();
		}

		protected override void OnLoad(EventArgs e)
		{
			base.OnLoad(e);

			Keys copy = Keys.Control | Keys.Alt | Keys.C;
			Keys paste = Keys.Control | Keys.Alt | Keys.V;
			registerHotkey(copy);
			registerHotkey(paste);
		}

		protected override void WndProc(ref Message m)
		{
			base.WndProc(ref m);

			if (m.Msg == WM_HOTKEY)
			{
				if ((int)m.LParam == COPY_PARAM)
					p.pastaCopy(PastaUtil.getClipboard());
				else if ((int)m.LParam == PASTE_PARAM)
					PastaUtil.setClipboard(p.pastaPaste());
			}
		}

		private void registerHotkey(Keys key)
		{
			int modifiers = 0;

			if ((key & Keys.Alt) == Keys.Alt)
				modifiers = modifiers | MOD_ALT;

			if ((key & Keys.Control) == Keys.Control)
				modifiers = modifiers | MOD_CONTROL;

			Keys k = key & ~Keys.Control & ~Keys.Alt;

			RegisterHotKey((IntPtr)this.Handle, keyId, modifiers, (int)k);
			keyId++;
		}
	}
}
