﻿// Utility functions for Copypasta
// Copyright (c) Michael Craft 2010
// Released under the MIT License.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Net;
using System.Web;

namespace libpasta
{
	public class PastaUtil
	{
		private String name;
		private String pass;
		private String server;

		public PastaUtil()
		{
			// config.txt can be in parent folder or same folder as exe
			StreamReader reader;
			try
			{
				reader = new StreamReader(Application.StartupPath + "\\..\\config.txt");
			}
			catch
			{
				reader = new StreamReader(Application.StartupPath + "\\config.txt");
			}
			reader.ReadLine();
			String line = reader.ReadLine(); // We want the second line
			String[] prefs = line.Split(',');
			this.name = prefs[0];
			this.pass = prefs[1];
			this.server = prefs[2];
		}

		// Get contents of a user's Copypasta clipboard
		public String pastaPaste()
		{
			String parameters = "type=pasta&name=" + HttpUtility.UrlEncode(name) + "&pass=" + HttpUtility.UrlEncode(pass);
			String response = httpPost(server, parameters);
			response = parseResponse(response);
			Console.WriteLine(response);
			return response;
		}

		// Sets the contents of a user's Copypasta clipboard
		public void pastaCopy(String pasta)
		{
			String parameters = "type=copy&name=" + HttpUtility.UrlEncode(name) + "&pass=" + HttpUtility.UrlEncode(pass) + "&pasta=" + HttpUtility.UrlEncode(pasta);
			String response = httpPost(server, parameters);
			Console.WriteLine(parseResponse(response));
		}

		public static String getClipboard()
		{
			return Clipboard.GetText();
		}

		public static void setClipboard(String pasta)
		{
			Clipboard.SetText(pasta);
		}

		// Returns the text inside <response> tags
		private String parseResponse(String response)
		{
			String[] delimiters = new String[] { "<response>", "</response>" };
			String[] parts = response.Split(delimiters, new StringSplitOptions());
			return parts[1];
		}

		// Ninja'd from http://en.csharp-online.net/HTTP_Post
		private String httpPost(String uri, String parameters)
		{
			// parameters: name1=value1&name2=value2	
			WebRequest webRequest = WebRequest.Create(uri);
			webRequest.ContentType = "application/x-www-form-urlencoded";
			webRequest.Method = "POST";
			byte[] bytes = Encoding.ASCII.GetBytes(parameters);
			Stream os = null;
			try
			{ // send the Post
				webRequest.ContentLength = bytes.Length;   //Count bytes to send
				os = webRequest.GetRequestStream();
				os.Write(bytes, 0, bytes.Length);         //Send it
			}
			catch (WebException ex)
			{
				Console.Error.WriteLine(ex.Message);
			}
			finally
			{
				if (os != null)
				{
					os.Close();
				}
			}

			try
			{ // get the response
				WebResponse webResponse = webRequest.GetResponse();
				if (webResponse == null) { return null; }
				StreamReader sr = new StreamReader(webResponse.GetResponseStream());
				return sr.ReadToEnd().Trim();
			}
			catch (WebException ex)
			{
				Console.Error.WriteLine(ex.Message);
			}
			return null;
		}
	}
}
